@@ -1,8 +1,8 @@
 /*
-  $Id: Common.h 15264 2012-10-10 10:13:54Z sloot $
+  $Id: Common.h 15854 2013-04-02 09:35:24Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Common.h $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -33,7 +33,6 @@
 #include <cmath>
 #include <cfloat>
 #include <cassert>
-#include <sys/time.h>
 
 namespace Common {
   const double Epsilon = DBL_EPSILON;   // smallest x so that 1+x != 1
@@ -69,25 +68,8 @@ namespace Common {
     // LOG base 2.
     if ( fabs(number) < Epsilon)
       return(0.0);
-    return(log(number) / log(2.0));
+    return log2(number);
   }
 
-  class Timer {
-  public:
-    friend std::ostream& operator << ( std::ostream& os, const Timer& T );
-    Timer(){ reset(); };
-    void reset(){ myTime.tv_sec=0; myTime.tv_usec=0; };
-    void start(){
-      gettimeofday( &startTime, 0 );
-    };
-    void stop();
-    unsigned int secs() { stop(); return myTime.tv_sec; };
-    std::string toString();
-    static std::string now();
-  private:
-    timeval startTime;
-    timeval myTime;
-  };
-
 }
 #endif
