@@ -1,8 +1,8 @@
 /*
-  $Id: IBtree.h 15266 2012-10-10 11:00:27Z sloot $
+  $Id: IBtree.h 15865 2013-04-02 13:24:34Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/IBtree.h $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -30,7 +30,7 @@
 #define TIMBL_IBTREE_H
 
 #include "ticcutils/TreeHash.h"
-#include "timbl/XMLtools.h"
+#include "ticcutils/XMLtools.h"
 
 //#define IBSTATS
 
