@@ -1,8 +1,8 @@
 /*
-  $Id: TimblExperiment.h 15264 2012-10-10 10:13:54Z sloot $
+  $Id: TimblExperiment.h 15865 2013-04-02 13:24:34Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/TimblExperiment.h $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -32,7 +32,7 @@
 
 #include <fstream>
 #include <set>
-#include "timbl/XMLtools.h"
+#include "ticcutils/XMLtools.h"
 #include "timbl/BestArray.h"
 #include "timbl/Statistics.h"
 #include "timbl/MBLClass.h"
