@@ -1,8 +1,8 @@
 /*
-  $Id: Choppers.cxx 15241 2012-10-02 11:26:24Z sloot $
+  $Id: Choppers.cxx 15828 2013-03-28 11:55:53Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Choppers.cxx $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -37,6 +37,7 @@
 #include "timbl/Choppers.h"
 
 using namespace std;
+using namespace TiCC;
 
 namespace Timbl{
 
@@ -456,7 +457,7 @@ namespace Timbl{
     string::size_type e_pos = strippedInput.find_first_of( "\t" );
     while ( e_pos != s_pos && e_pos != string::npos && i < vSize ){
       // stop if a zero length string is found or if too many entries show up
-      choppedInput[i++] = string( strippedInput, s_pos, e_pos - s_pos );
+      choppedInput[i++] = StrToCode( string( strippedInput, s_pos, e_pos - s_pos ) );
       s_pos = strippedInput.find_first_not_of( "\t", e_pos );
       e_pos = strippedInput.find_first_of( "\t", s_pos );
     }
