@@ -1,8 +1,8 @@
 /*
-  $Id: IBtree.cxx 15266 2012-10-10 11:00:27Z sloot $
+  $Id: IBtree.cxx 15879 2013-04-02 16:05:03Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/IBtree.cxx $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -38,14 +38,15 @@
 
 #include "ticcutils/StringOps.h"
 #include "ticcutils/TreeHash.h"
+#include "ticcutils/XMLtools.h"
 #include "timbl/Common.h"
 #include "timbl/MsgClass.h"
 #include "timbl/Types.h"
 #include "timbl/Instance.h"
-#include "timbl/XMLtools.h"
 #include "timbl/IBtree.h"
 
 using namespace std;
+using namespace TiCC;
 
 namespace Timbl {
   using namespace Common;
@@ -314,17 +315,17 @@ namespace Timbl {
     while ( pnt ){
       xmlNode *node = XmlNewChild( nodes, "node" );
       if ( pnt->FValue )
-	XmlAddChild( node, to_node( pnt->FValue ) );
+	xmlAddChild( node, to_node( pnt->FValue ) );
       if ( pnt->TValue )
-	XmlAddChild( node, to_node( pnt->TValue ) );
+	xmlAddChild( node, to_node( pnt->TValue ) );
       if ( pnt->link ){
 	if ( pnt->link->FValue )
-	  XmlAddChild( node, to_xml(pnt->link) );
+	  xmlAddChild( node, to_xml(pnt->link) );
 	else if ( pnt->link->TDistribution )
-	  XmlAddChild( node, to_node( pnt->link->TDistribution ) );
+	  xmlAddChild( node, to_node( pnt->link->TDistribution ) );
       }
       else if ( pnt->TDistribution )
-	XmlAddChild( node, to_node( pnt->TDistribution ) );
+	xmlAddChild( node, to_node( pnt->TDistribution ) );
       pnt = pnt->next;
     }
     return nodes;
@@ -334,14 +335,14 @@ namespace Timbl {
     // save an IBtree for later use.
     XmlDoc doc( "root" );
     xmlNode *root = doc.getRoot();
-    XmlAddChild( root, XmlNewComment( "Version " + toString(Version) ) );
+    xmlAddChild( root, XmlNewComment( "Version " + toString(Version) ) );
     bool dummy;
-    XmlAddChild( root, to_node( TopTarget( dummy ) ) );
+    xmlAddChild( root, to_node( TopTarget( dummy ) ) );
     if ( PersistentDistributions )
-      XmlAddChild( root, to_node( TopDistribution ) );
+      xmlAddChild( root, to_node( TopDistribution ) );
     IBtree *pnt = InstBase;
     xmlNode *tree = to_xml( pnt );
-    XmlAddChild( root, tree );
+    xmlAddChild( root, tree );
     os << doc << endl;
   }  
   
