@@ -1,8 +1,8 @@
 /*
-  $Id: IGExperiment.cxx 15266 2012-10-10 11:00:27Z sloot $
+  $Id: IGExperiment.cxx 15854 2013-04-02 09:35:24Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/IGExperiment.cxx $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -43,9 +43,11 @@
 #include "timbl/Instance.h"
 #include "timbl/IBtree.h"
 #include "timbl/TimblExperiment.h"
+#include "ticcutils/Timer.h"
 
 namespace Timbl {
   using namespace std;
+  using namespace TiCC;
 
   void IG_Experiment::InitInstanceBase(){
     srand( RandomSeed() );
@@ -121,7 +123,7 @@ namespace Timbl {
       result = false;
     }
     if ( result ) {
-      Common::Timer learnT;
+      Timer learnT;
       learnT.start();
       InitInstanceBase();
       if ( ExpInvalid() )
