@@ -1,8 +1,8 @@
 /*
-  $Id: MBLClass.cxx 15266 2012-10-10 11:00:27Z sloot $
+  $Id: MBLClass.cxx 15868 2013-04-02 14:05:58Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/MBLClass.cxx $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -62,6 +62,7 @@
 #include "timbl/MBLClass.h"
 
 using namespace std;
+using namespace TiCC;
 
 namespace Timbl {
 
@@ -427,7 +428,7 @@ namespace Timbl {
       if ( TiCC::split_at( lines[i], parts, ":" ) ==2 ){
 	string tag = TiCC::trim( parts[0] );
 	string val = TiCC::trim( parts[1] );
-	XmlNewChild( result, tag, val );
+	XmlNewTextChild( result, tag, val );
       }
     }
     return result;
