@@ -1,8 +1,8 @@
 /*
-  $Id: TimblAPI.cxx 15266 2012-10-10 11:00:27Z sloot $
+  $Id: TimblAPI.cxx 15828 2013-03-28 11:55:53Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/TimblAPI.cxx $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -43,6 +43,9 @@ using namespace std;
 
 #include "timbl/TimblAPI.h"
 #include "timbl/TimblExperiment.h"
+
+using namespace TiCC;
+
 namespace Timbl {
   
   TimblOpts::TimblOpts( const int argc, const char * const *argv ):
@@ -568,6 +571,14 @@ namespace Timbl {
     return false;
   }
   
+  double TimblAPI::GetAccuracy() {
+    if (Valid()) {
+        return pimpl->stats.testedCorrect()/(double) pimpl->stats.dataLines();
+    } else {
+        return -1;
+    }
+  }
+  
   Weighting TimblAPI::CurrentWeighting() const{
     if ( Valid() )
       return WT_to_W( pimpl->CurrentWeighting() );
