@@ -1,8 +1,8 @@
 /*
-  $Id: TimblExperiment.cxx 15266 2012-10-10 11:00:27Z sloot $
+  $Id: TimblExperiment.cxx 15868 2013-04-02 14:05:58Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/TimblExperiment.cxx $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -64,16 +64,18 @@
 #include "timbl/CommandLine.h"
 #include "timbl/GetOptClass.h"
 #include "timbl/TimblExperiment.h"
-#include "timbl/XMLtools.h"
+#include "ticcutils/XMLtools.h"
+#include "ticcutils/Timer.h"
 
 #ifdef HAVE_OPENMP
 #include <omp.h>
 #endif
 
 using namespace std;
+using namespace TiCC;
 
 namespace Timbl {
-  #include "ticcutils/PrettyPrint.h"
+#include "ticcutils/PrettyPrint.h"
   using namespace TiCC;
 
   resultStore::~resultStore( ) {
@@ -395,7 +397,7 @@ namespace Timbl {
 	      result = false;
 	    }
 	    else {
-	      Common::Timer prepT;
+	      Timer prepT;
 	      prepT.start();
 	      bool found;
 	      bool go_on = true;
@@ -517,7 +519,7 @@ namespace Timbl {
   bool TimblExperiment::ClassicLearn( const string& FileName, 
 				      bool warnOnSingleTarget ){
     bool result = true;
-    Common::Timer learnT;
+    Timer learnT;
     if ( is_synced ){
       CurrentDataFile = FileName; // assume magic!
     }
@@ -539,14 +541,14 @@ namespace Timbl {
       result = false;
     }
     if ( result ) {
-      Common::Timer learnT;
+      Timer learnT;
       learnT.start();
       InitInstanceBase();
       if ( ExpInvalid() )
 	return false;
       if ( EffectiveFeatures() < 2 ) {
 	fileIndex fmIndex;
-	//      Common::Timer t;
+	//      Timer t;
 	//      t.start();
 	result = build_file_index( CurrentDataFile, fmIndex );
 	//      t.stop();
@@ -568,7 +570,7 @@ namespace Timbl {
       }
       else {
 	fileDoubleIndex fIndex;
-	//      Common::Timer t;
+	//      Timer t;
 	//      t.start();
 	result = build_file_multi_index( CurrentDataFile, fIndex );
 	//	cerr << "index: " << fIndex << endl;
@@ -1100,7 +1102,7 @@ namespace Timbl {
     }
     else {
       bool result = true;
-      Common::Timer learnT;
+      Timer learnT;
       if ( ExpInvalid() ||
 	   !ConfirmOptions() ){
 	result = false;
@@ -2055,7 +2057,7 @@ namespace Timbl {
     vector<double> wghts;
     GetCurrentWeights( wghts );
     for ( unsigned int i=0; i < wghts.size(); ++i ){
-      xmlNode *n = XmlNewChild( result, "feature", toString(wghts[i]) );
+      xmlNode *n = XmlNewTextChild( result, "feature", toString(wghts[i]) );
       XmlSetAttribute( n, "index", toString(i+1) );
     }
     return result;
